Mailing Lists — ASE documentation

### Navigation

- index
- modules |

# Mailing Lists

There is a mailing list for discussing ASE:

- ase-users

The mailing lists below are of interest for active ASE developers only:

- ase-developers
- ase-svncheckins

## Internet Relay Chat

We have the IRC channel `#ase` on FreeNode. Please join us if you have any questions. For easy access, you can use this webclient.

### Navigation

- index
- modules |